==> graphx-0.9.11.tar.gz: example/lib/main.dart <==
import 'package:flutter/material.dart';

import 'demos/demos.dart';

void main() {
  runApp(
    MaterialApp(
      // home: SimpleShapesMain(),
      // home: SimpleTweenMain(),
      // home: DemoSvgIconsMain(),
      // home: SimpleInteractionsMain(),
      // home: GraphicsClipperDemo(),
      // home: FacebookReactionsMain(),
      // home: DrippingIVMain(),
      // home: ChartMountainMain(),
      // home: GlowingCircleMain(),
      // home: SortingButtonMain(),
      // home: BookmarkButtonMain(),
      // home: SubmitButtonMain(),
      // home: CardRotation3dMain(),
      // home: RasterDrawMain(),
      // home: DialerMain(),
      // home: GaugeMeterMain(),
      // home: SpiralLoaderMain(),
      // home: UniversoFlutterIntroMain(),
      // home: ColorfulLoaderMain(),
      // home: JellyThingMain(),
      // home: BallVsLineMain(),
      // home: Dna3dMain(),
      // home: SplashIntroMain(),
      // home: LinedButtonMain(),
      // home: ColorPickerMain(),
      // home: AltitudeIndicatorMain(),
      // home: BreakoutMain(),
      // home: XmasMain(),
      // home: SimpleRadialMenuMain(),
      // home: MuratCoffeeMain(),
      // home: PieChartMain(),
      // home: ChartBezierMain(),
      // home: RunHeroCanvasMain(),
      // home: ElasticBandMain(),
      // home: FlowerGradientMain(),
      // home: NokiaSnakeMain(),
      // home: HeartReactionMain(),
      // home: SimpleToastMain(),
      // home: RatingStarsMain(),
      // home: PizzaBoxMain(),
      // home: DrawingPadBezierMain(),
      // home: IsmaChartMain(),
      home: TriGridMain(),
      // home: NicoLoadingIndicatorMain(),
      // home: FeelingSwitchMain(),
      // home: MouseRepulsionMain(),
      // home: Globe3dMain(),
      // home: LungsAnimationMain(),
      // home: PathChartStressTestMain(),
      // home: ExpanderFabMenu(),
      // home: PageIndicatorMain(),
    ),
  );
}

==> graphx-1.0.1.tar.gz: example/lib/main.dart <==
import 'package:flutter/material.dart';

import 'demos/demos.dart';

void main() {
  runApp(
    MaterialApp(
      // home: SimpleShapesMain(),
      // home: SimpleTweenMain(),
      // home: DemoSvgIconsMain(),
      // home: SimpleInteractionsMain(),
      home: GraphicsClipperDemo(),
      // home: FacebookReactionsMain(),
      // home: DrippingIVMain(),
      // home: ChartMountainMain(),
      // home: GlowingCircleMain(),
      // home: SortingButtonMain(),
      // home: BookmarkButtonMain(),
      // home: SubmitButtonMain(),
      // home: CardRotation3dMain(),
      // home: RasterDrawMain(),
      // home: DialerMain(),
      // home: GaugeMeterMain(),
      // home: SpiralLoaderMain(),
      // home: UniversoFlutterIntroMain(),
      // home: ColorfulLoaderMain(),
      // home: JellyThingMain(),
      // home: BallVsLineMain(),
      // home: Dna3dMain(),
      // home: SplashIntroMain(),
      // home: LinedButtonMain(),
      // home: ColorPickerMain(),
      // home: AltitudeIndicatorMain(),
      // home: BreakoutMain(),
      // home: XmasMain(),
      // home: SimpleRadialMenuMain(),
      // home: MuratCoffeeMain(),
      // home: PieChartMain(),

      // home: ChartBezierMain(),

      // home: RunHeroCanvasMain(),
      // home: ElasticBandMain(),
      // home: FlowerGradientMain(),
      // home: NokiaSnakeMain(),
      // home: HeartReactionMain(),
      // home: SimpleToastMain(),
      // home: RatingStarsMain(),
      // home: PizzaBoxMain(),
      // home: DrawingPadBezierMain(),
      // home: IsmaChartMain(),
      // home: TriGridMain(),
      // home: NicoLoadingIndicatorMain(),
      // home: FeelingSwitchMain(),
      // home: MouseRepulsionMain(),
      // home: Globe3dMain(),
      // home: LungsAnimationMain(),
      // home: ExpanderFabMenu(),
      // home: PageIndicatorMain(),
    ),
  );
}
